// Copyright 2016 Gomez Guillaume
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

pub const MOD_COMMENT: &str = "<!-- ";
pub const FILE_COMMENT: &str = "<!-- file_comment";
pub const FILE: &str = "<!-- file ";
pub const END_INFO: &str = " -->";
pub const OUTPUT_COMMENT_FILE: &str = "comments.md";
